﻿using Microsoft.VisualStudio.TestTools.UnitTesting;
using Navigation;

namespace Survey.Test
{
	[TestClass]
	[DeploymentItem(@"Survey\StateInfo.config")]
	public class SurveyControllerTest
	{
		[TestMethod]
		public void UpdateQuestion1NavigatesToQuestion2IfAnswerIsWebForms()
		{
			StateController.Navigate("Survey");
			SurveyController controller = new SurveyController();
			Question question = new Question() { Answer = "Web Forms" };
			
			controller.UpdateQuestion1(question);
			
			Assert.AreEqual("Question2", StateContext.State.Key);
		}

		[TestMethod]
		public void UpdateQuestion1NavigatesToThanksIfAnswerIsMVC()
		{
			StateController.Navigate("Survey");
			SurveyController controller = new SurveyController();
			Question question = new Question() { Answer = "MVC" };
			
			controller.UpdateQuestion1(question);
			
			Assert.AreEqual("Thanks", StateContext.State.Key);
		}

		[TestMethod]
		public void UpdateQuestion1PassesTechnologyAnswer()
		{
			StateController.Navigate("Survey");
			SurveyController controller = new SurveyController();
			Question question = new Question() { Answer = "Web Forms" };
			
			controller.UpdateQuestion1(question);
			
			Assert.AreEqual("Web Forms", (string)StateContext.Data["technology"]);
		}

		[TestMethod]
		public void UpdateQuestion1StoresAnswer()
		{
			StateController.Navigate("Survey");
			SurveyController controller = new SurveyController();
			Question question = new Question() { Answer = "Web Forms" };
			
			controller.UpdateQuestion1(question);
			
			Assert.AreEqual("Web Forms", (string)StateController.Crumbs[0].Data["answer"]);
		}

		[TestMethod]
		public void UpdateQuestion2NavigatesToThanks()
		{
			StateController.Navigate("Survey");
			StateController.Navigate("Next", new NavigationData() { { "technology", "Web Forms" } });
			SurveyController controller = new SurveyController();
			Question question = new Question() { Answer = "Yes" };
			
			controller.UpdateQuestion2(question);
			
			Assert.AreEqual("Thanks", StateContext.State.Key);
		}

		[TestMethod]
		public void UpdateQuestion2PassesNavigationTrueIfAnswerYes()
		{
			StateController.Navigate("Survey");
			StateController.Navigate("Next", new NavigationData() { { "technology", "Web Forms" } });
			SurveyController controller = new SurveyController();
			Question question = new Question() { Answer = "Yes" };
			
			controller.UpdateQuestion2(question);
			
			Assert.AreEqual(true, (bool)StateContext.Data["navigation"]);
		}

		[TestMethod]
		public void UpdateQuestion2PassesNavigationFalseIfAnswerNo()
		{
			StateController.Navigate("Survey");
			StateController.Navigate("Next", new NavigationData() { { "technology", "Web Forms" } });
			SurveyController controller = new SurveyController();
			Question question = new Question() { Answer = "No" };
			
			controller.UpdateQuestion2(question);
			
			Assert.AreEqual(false, (bool)StateContext.Data["navigation"]);
		}

		[TestMethod]
		public void UpdateQuestion2PassesTechnologyAnswerPassedIn()
		{
			StateController.Navigate("Survey");
			StateController.Navigate("Next", new NavigationData() { { "technology", "Web Forms" } });
			SurveyController controller = new SurveyController();
			Question question = new Question() { Answer = "No" };
			
			controller.UpdateQuestion2(question);
			
			Assert.AreEqual("Web Forms", (string)StateContext.Data["technology"]);
		}

		[TestMethod]
		public void UpdateQuestion2StoresAnswer()
		{
			StateController.Navigate("Survey");
			StateController.Navigate("Next", new NavigationData() { { "technology", "Web Forms" } });
			SurveyController controller = new SurveyController();
			Question question = new Question() { Answer = "Yes" };
			
			controller.UpdateQuestion1(question);
			
			Assert.AreEqual("Yes", (string)StateController.Crumbs[1].Data["answer"]);
		}
	}
}
